@@ -22,12 +22,13 @@ use Log::Log4perl qw(get_logger);
 use Params::Validate qw(:all);
 
 use perfSONAR_PS::Common;
-use perfSONAR_PS::XML::Document_string;
+use perfSONAR_PS::XML::Document_file;
 use perfSONAR_PS::Messages;
 use perfSONAR_PS::Error_compat qw/:try/;
 use perfSONAR_PS::EventTypeEquivalenceHandler;
+use perfSONAR_PS::ParameterValidation;
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 =head1 API
 =cut
@@ -60,7 +61,7 @@ sub new {
     function.
 =cut
 sub registerMergeHandler {
-    my ($self, $messageType, $eventTypes, $service) = validate_pos(@_,
+    my ($self, $messageType, $eventTypes, $service) = validateParamsPos(@_,
             1,
             { type => SCALAR },
             { type => ARRAYREF },
@@ -104,7 +105,7 @@ sub registerEventEquivalence {
     message.
 =cut
 sub registerFullMessageHandler {
-    my ($self, $messageType, $service) = validate_pos(@_,
+    my ($self, $messageType, $service) = validateParamsPos(@_,
                 1,
                 { type => SCALAR },
                 { can => 'handleMessage'},
@@ -136,7 +137,7 @@ sub registerFullMessageHandler {
     been handled.
 =cut
 sub registerMessageHandler {
-    my ($self, $messageType, $service) = validate_pos(@_,
+    my ($self, $messageType, $service) = validateParamsPos(@_,
                 1,
                 { type => SCALAR },
                 { can => [ 'handleMessageBegin', 'handleMessageEnd', 'handleEvent' ]}
@@ -162,7 +163,7 @@ sub registerMessageHandler {
     specified type found in a message of the specified type.
 =cut
 sub registerEventHandler {
-    my ($self, $messageType, $eventType, $service) = validate_pos(@_,
+    my ($self, $messageType, $eventType, $service) = validateParamsPos(@_,
                 1,
                 { type => SCALAR },
                 { type => SCALAR },
@@ -194,7 +195,7 @@ sub registerEventHandler {
     type.
 =cut
 sub registerEventHandler_Regex {
-    my ($self, $messageType, $eventRegex, $service) = validate_pos(@_,
+    my ($self, $messageType, $eventRegex, $service) = validateParamsPos(@_,
                 1,
                 { type => SCALAR },
                 { type => SCALAR },
@@ -223,9 +224,9 @@ sub registerEventHandler_Regex {
 =cut
 sub __handleMessage {
     my ($self, @args) = @_;
-    my $args = validate(@args, 
+    my $args = validateParams(@args, 
             {
-                output => { type => ARRAYREF, isa => "perfSONAR_PS::XML::Document_string" },
+                output => { type => ARRAYREF, isa => "perfSONAR_PS::XML::Document_file" },
                 messageId => { type => SCALAR },
                 messageType => { type => SCALAR },
                 message => { type => SCALARREF },
@@ -248,9 +249,9 @@ sub __handleMessage {
 =cut
 sub __handleMessageBegin {
     my ($self, @args) = @_;
-    my $args = validate(@args, 
+    my $args = validateParams(@args, 
             {
-                output => { type => ARRAYREF, isa => "perfSONAR_PS::XML::Document_string" },
+                output => { type => ARRAYREF, isa => "perfSONAR_PS::XML::Document_file" },
                 messageId => { type => SCALAR | UNDEF },
                 messageType => { type => SCALAR },
                 messageParameters => { type => HASHREF | UNDEF },
@@ -278,9 +279,9 @@ sub __handleMessageBegin {
 =cut
 sub __handleMessageEnd {
     my ($self, @args) = @_;
-    my $args = validate(@args, 
+    my $args = validateParams(@args, 
             {
-                output => { type => ARRAYREF, isa => "perfSONAR_PS::XML::Document_string" },
+                output => { type => ARRAYREF, isa => "perfSONAR_PS::XML::Document_file" },
                 messageId => { type => SCALAR | UNDEF },
                 messageType => { type => SCALAR },
                 message => { type => SCALARREF },
@@ -307,9 +308,9 @@ sub __handleMessageEnd {
 =cut
 sub __handleEvent {
     my ($self, @args) = @_;
-    my $args = validate(@args, 
+    my $args = validateParams(@args, 
             {
-                output => { type => ARRAYREF, isa => "perfSONAR_PS::XML::Document_string" },
+                output => { type => ARRAYREF, isa => "perfSONAR_PS::XML::Document_file" },
                 messageId => { type => SCALAR | UNDEF },
                 messageType => { type => SCALAR },
                 messageParameters => { type => HASHREF | UNDEF },
@@ -451,7 +452,7 @@ sub handleMessage {
         my ($errorEventType, $errorMessage);
 
         try {
-            my $ret_message = new perfSONAR_PS::XML::Document_string();
+            my $ret_message = new perfSONAR_PS::XML::Document_file();
             $self->__handleMessage({ output => $ret_message, messageId => $messageId, messageType => $messageType, message => $message, rawRequest => $raw_request });
             $raw_request->setResponse($ret_message->getValue());
         }
@@ -477,7 +478,7 @@ sub handleMessage {
         };
 
         if (defined $errorEventType) {
-            my $ret_message = new perfSONAR_PS::XML::Document_string();
+            my $ret_message = new perfSONAR_PS::XML::Document_file();
             my $retMessageId = "message.".genuid();
 
             # we weren't given a return message type, so try to construct
@@ -521,7 +522,7 @@ sub handleMessage {
         }
     }
 
-    my $ret_message = perfSONAR_PS::XML::Document_string->new();
+    my $ret_message = perfSONAR_PS::XML::Document_file->new();
 
     my $doOutputMessageHeader = 1;
     my $doOutputMetadata = 0;
@@ -693,6 +694,7 @@ sub handleMessage {
     }
 
     $raw_request->setResponse($ret_message->getValue());
+    $raw_request->finish();
 
     return;
 }
@@ -941,7 +943,7 @@ __END__
 
 =head1 SEE ALSO
 
-L<Log::Log4perl>, L<perfSONAR_PS::XML::Document_string>
+L<Log::Log4perl>, L<perfSONAR_PS::XML::Document_file>
 L<perfSONAR_PS::Common>, L<perfSONAR_PS::Messages>
 
 To join the 'perfSONAR-PS' mailing list, please visit:
