@@ -21,8 +21,9 @@ use Params::Validate qw(:all);
 
 use perfSONAR_PS::Common;
 use perfSONAR_PS::Messages;
+use perfSONAR_PS::ParameterValidation;
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 =head1 API
 =cut
@@ -75,7 +76,7 @@ sub registerLS {
 =cut
 sub handleEvent {
 	my ($self, @args) = @_;
-	my $parameters = validate(@args,
+	my $parameters = validateParams(@args,
 			{
 			output => 1,
 			messageId => 1,
